@@ -17,11 +17,11 @@
 import testscenarios
 
 from oslo_log import log as logging
+from tempest.common import utils
 from tempest import config
 from tempest.lib.common.utils import test_utils
 from tempest.lib import decorators
 from tempest.lib import exceptions as lib_exc
-from tempest import test
 
 from neutron_fwaas.tests.tempest_plugin.tests.scenario import base
 
@@ -46,7 +46,7 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
         # if self.router_insertion:
         #    required_exts.append('fwaasrouterinsertion')
         for ext in required_exts:
-            if not test.is_extension_enabled(ext, 'network'):
+            if not utils.is_extension_enabled(ext, 'network'):
                 msg = "%s Extension not enabled." % ext
                 raise self.skipException(msg)
         LOG.debug("FWaaSScenarioTest Setup done.")
@@ -140,7 +140,7 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
             network, security_group=security_group)
         private_key = keys['private_key']
         server_floating_ip = self.create_floating_ip(server, pub_network_id)
-        fixed_ip = server['addresses'].values()[0][0]['addr']
+        fixed_ip = list(server['addresses'].values())[0][0]['addr']
         return server, private_key, fixed_ip, server_floating_ip
 
     def _create_topology(self):
